@@ -1,7 +1,7 @@
 package LEOCHARRE::Class::Accessors::Base;
 use strict;
-use Carp;
 use warnings;
+use LEOCHARRE::DEBUG;
 use vars qw(@ISA @EXPORT $VERSION);
 use Exporter;
 @ISA = qw/ Exporter /;
@@ -11,11 +11,13 @@ _make_accessor_multi
 _make_accessor_dual
 _make_new
 );
-$VERSION = sprintf "%d.%02d", q$Revision: 1.4 $ =~ /(\d+)/g;
+$VERSION = sprintf "%d.%02d", q$Revision: 1.2 $ =~ /(\d+)/g;
+
+#$LEOCHARRE::Class::Accessors::Base::DEBUG=0;
 
 #no warnings 'redefine';
-my $DEBUG = 0;
-sub DEBUG : lvalue  { $DEBUG }
+
+#sub DEBUG : lvalue { $LEOCHARRE::Class::Accessors::Base::DEBUG }
 
 sub _make_new {
    my $class = shift;
@@ -454,8 +456,6 @@ sub _make_accessor_data {
 
 1;
 
-__END__
-
 =pod
 
 =head1 NAME
